Retrieves session settings
pa_get_settings.RdIt allows to override specific settings, without changing environment variables.
Arguments
- base_url
The base URL of the Plausible instance. Set to https://plausible.io/ - or to your own domain for self-hosted Plausible.
- site_id
Corresponds to the domain of your website.
- key
A character string used for authentication. Can be retrieved from the user settings in Plausible Analytics.
Examples
pa_set(
base_url = "https://plausible.io/",
site_id = "example.com",
key = "actual_key_here"
)
pa_get_settings()
## It allows to override specific settings, without changing environment variables
pa_get_settings(site_id = "notexample.com")