Skip to contents

Get most visited pages for a given period

Usage

pa_get_top_pages(period = "30d", limit = 100)

Arguments

period

Period to include in the analysis, defaults to 30d. See examples as well as the the official documentation for valid values.

limit

Limit the number of results. Defaults to 100.

Value

A data frame.

Examples

if (FALSE) { # \dontrun{
pa_get_top_pages(period = "6mo")
} # }